@@ -270,9 +270,9 @@ class JobStatus(object):
         self.jobStage = None
         self.terminalStage = None
         self.failed = None
-        self.metadata = None
+        self.metadata = {} 
         self.dateSubmitted = None
-        self.messages = [ ] 
+        self.messages = [] 
         self.commandline = None
 
     def __parseJobStatus__(self, xml):
@@ -299,6 +299,10 @@ class JobStatus(object):
         if xml.find("messages") is not None:
             for m in xml.find("messages"):
                 self.messages.append("%s: %s" % (m.find("timestamp").text, m.find("text").text))
+        if xml.find("metadata") is not None:
+            for e in xml.find("metadata").findall("entry"):
+            # for m in xml.find("entry"):
+                self.metadata[e.find("key").text] = e.find("value").text
 
     def show(self, messages=False):
         """ A debugging method to dump some of the content of this object to stdout """
@@ -319,7 +323,12 @@ class JobStatus(object):
         if messages:
             for m in self.messages:
                 print("\t%s" % (m))
-            
+            if self.metadata:
+                print("Metadata:")
+                for key in self.metadata:
+                    print("\t%s=%s" % (key, self.metadata[key]))
+            else:
+                print("There is no metadata")
 
     def update(self):
         r = self.client.__doGet__(url=self.jobUrl + "/?expand=true")
