@@ -43,6 +43,9 @@ import sys,os
 import re
 import time
 import traceback
+from io import IOBase
+
+PY3 = sys.version_info > (3,)
 
 
 class IllegalArgumentException(Exception):
@@ -81,7 +84,7 @@ class Properties(object):
 
     def __str__(self):
         s='{'
-        for key,value in self._props.items():
+        for key,value in list(self._props.items()):
             s = ''.join((s,key,'=',value,', '))
 
         s=''.join((s[:-2],'}'))
@@ -181,7 +184,7 @@ class Properties(object):
             # same property
             while line[-1] == '\\':
                 # Read next line
-                nextline = i.next()
+                nextline = next(i)
                 nextline = nextline.strip()
                 lineno += 1
                 # This line will become part of the value
@@ -230,14 +233,14 @@ class Properties(object):
 
         for f in found:
             srcKey = f[1:-1]
-            if self._props.has_key(srcKey):
+            if srcKey in self._props:
                 value = value.replace(f, self._props[srcKey], 1)
 
         # Terri: changed this.  Value is always a list and 0th value in list is always the last one added.
         self._props.setdefault(key, []).insert(0, value.strip())
 
         # Check if an entry exists in pristine keys
-        if self._keymap.has_key(key):
+        if key in self._keymap:
             oldkey = self._keymap.get(key)
             self._origprops[oldkey] = oldvalue.strip()
         else:
@@ -270,16 +273,16 @@ class Properties(object):
         """ Load properties from an open file stream """
 
         # For the time being only accept file input streams
-        if type(stream) is not file:
-            raise TypeError,'Argument should be a file object!'
+        if (PY3 and not isinstance(stream, IOBase)) or (not PY3 and not isinstance(stream, file)):
+            raise TypeError('Argument should be a file object!')
         # Check for the opened mode
         if stream.mode != 'r':
-            raise ValueError,'Stream should be opened in read-only mode!'
+            raise ValueError('Stream should be opened in read-only mode!')
 
         try:
             lines = stream.readlines()
             self.__parse(lines)
-        except IOError, e:
+        except IOError as e:
             raise
 
     # Terri: added this method.  Returns None if key isn't in the dictionary
@@ -299,20 +302,20 @@ class Properties(object):
         if type(key) is str and type(value) is str:
             self.processPair(key, value)
         else:
-            raise TypeError,'both key and value should be strings!'
+            raise TypeError('both key and value should be strings!')
 
     def propertyNames(self):
         """ Return an iterator over all the keys of the property
         dictionary, i.e the names of the properties """
 
-        return self._props.keys()
+        return list(self._props.keys())
 
     def list(self, out=sys.stdout):
         """ Prints a listing of the properties to the
         stream 'out' which defaults to the standard output """
 
         out.write('-- listing properties --\n')
-        for key,value in self._props.items():
+        for key,value in list(self._props.items()):
             # out.write(''.join((key,'='value,'\n')))
             if not value or not len(value):
                 out.write(''.join((key,'=','\n')))
@@ -326,7 +329,7 @@ class Properties(object):
         with the optional 'header' """
 
         if out.mode[0] != 'w':
-            raise ValueError,'Steam should be opened in write mode!'
+            raise ValueError('Steam should be opened in write mode!')
 
         try:
             out.write(''.join(('#',header,'\n')))
@@ -340,7 +343,7 @@ class Properties(object):
                     out.write(''.join((prop,'=',self.escape(val),'\n')))
 
             out.close()
-        except IOError, e:
+        except IOError as e:
             raise
 
     # Terri: returns the internal dictionary converted such each value is a string, the first one in the list from the raw dict 
@@ -390,11 +393,11 @@ if __name__=="__main__":
     p = Properties()
     p.load(open('test2.properties'))
     p.list()
-    print p
-    print p.items()
-    print p['name3']
+    print(p)
+    print(list(p.items()))
+    print(p['name3'])
     p['name3'] = 'changed = value'
-    print p['name3']
+    print(p['name3'])
     p['new key'] = 'new value'
     p.store(open('test2.properties','w'))
-    print p.name3
+    print(p.name3)
